library("sf")
library(reshape2)
library(ggplot2)
library(marmap)
library(dplyr)
library(maptools)
library(rworldmap)
library(rworldxtra)
library(ggpubr)


worldMap <- getMap(resolution = "high")[which(getMap(resolution = "high")$ADMIN%in%c("Norway", "Russia", "Sweden", "Finland")),]
ggworldMap<-fortify(worldMap)
usespecies.df<-data.frame(usespecies= c("TORSK", "HYSE", "SNABELUER"), usespeciesENG = c("Cod", "Haddock" , "B_redfish"))
colors<-c(Adult = "#2364AA", Juvenile = "#931621")
agegroups<-list("Haddock"= c(1:9,17), "B_redfish" = c(1,11,64), "Cod"=c(1:9, 18))
Pal<-c("white","#90D4CE","#D8C160","#D34C25","#5F0B15")

ewbrks <- seq(0, 50,25)
nsbrks <- seq(65, 80,5)
ewlbls <- unlist(lapply(ewbrks, function(x) ifelse(x < 0, paste0(x, "°W"), ifelse(x > 0, paste0(x, "°E"),x))))
nslbls <- unlist(lapply(nsbrks, function(x) ifelse(x < 0, paste0(x, "°S"), ifelse(x > 0, paste0(x, "°N"),x))))

a<-6400
sp<-3
yrs<-1985:2016
art<-usespecies.df[sp, 1]
species<-usespecies.df[sp, 2]

source("C:/Users/jonatanf/Documents/Hexagon.R")
setwd("C:/Users/jonatanf/Documents/Chapter2/R.scripts")
load(file = paste0("ylu_",a,"_list.rda"))

  print(paste(art))
  
  # LOADING DATA ####
  print("Getting density data for ages:")

  sp<-3
  Offs<-0  

      art<-usespecies.df[sp, 1]
      species<-usespecies.df[sp, 2]
      
      # subset the data
      ylu<-ylu_list[[paste(species,Offs,sep = "_")]]

    
  YearsSampled<-rowSums(rowSums(ylu, dim = 2, na.rm = TRUE)) != 0
  AgeSampled<-rowSums(ylu, dims = 2, na.rm= TRUE)>0
  AgeSampled<-AgeSampled[YearsSampled,]
  
  e.ylu<-exp(ylu)-1        
  AG.ylu<-rowSums(e.ylu[YearsSampled,,1:10], dim =2)
  AG.ylu[AgeSampled == FALSE]<-NA
  log.AG.ylu<-log(AG.ylu+1)
  log.AG.ylu[abs(log.AG.ylu)==Inf] <- NA 
  log.AG.ylu<-colMeans(log.AG.ylu, na.rm = TRUE)
  log.AG.ylu<-log.AG.ylu/max(log.AG.ylu, na.rm= TRUE)
  log.AG.ylu.df<-melt(log.AG.ylu)
  log.AG.ylu.df$gridid<-rownames(log.AG.ylu.df)
  colnames(log.AG.ylu.df)<-c("Density","gridid")
  log.AG.ylu.df$Stage<-"Juveniles"
  #####################################################################
  e.ylu<-exp(ylu)-1        
  AG.ylu<-rowSums(e.ylu[YearsSampled,,11:63], dim =2)
  AG.ylu[AgeSampled == FALSE]<-NA
  log.AG.ylu<-log(AG.ylu+1)
  log.AG.ylu[abs(log.AG.ylu)==Inf] <- NA 
  log.AG.ylu<-colMeans(log.AG.ylu, na.rm = TRUE)
  log.AG.ylu<-log.AG.ylu/max(log.AG.ylu, na.rm= TRUE)
  temp.ylu<-melt(log.AG.ylu)
  temp.ylu$gridid<-rownames(temp.ylu)
  colnames(temp.ylu)<-c("Density","gridid")
  temp.ylu$Stage<-"Adults"
  log.AG.ylu.df<-rbind(log.AG.ylu.df, temp.ylu)
  ####################################################################
  hex_grid_LL_df<-fortify(hex_grid_LL_M)
  hex_grid_LL_df<-merge(log.AG.ylu.df, hex_grid_LL_df, by.x = "gridid", by.y = "id")
  hex_grid_LL_dfBR<-hex_grid_LL_df[order(hex_grid_LL_df$group, hex_grid_LL_df$order),]
  hex_grid_LL_dfBR$Species<-"Beaked redfish"
  
  Range<-hex_grid_LL_M[unique(hex_grid_LL_df[!is.na(hex_grid_LL_df$Density),'gridid'])]
  RangeBR<-fortify(aggregate(Range))
  
  hex_grid_LL_dfBR$Stage<-factor(hex_grid_LL_dfBR$Stage, levels = c("Juveniles", "Adults"))
  
  BeakedStagesMap<-ggplot(hex_grid_LL_dfBR[!is.na(hex_grid_LL_dfBR$Density),], aes(long, lat))+
    geom_polygon(aes(fill = Density, group= group))+
    scale_fill_gradientn(colors = Pal, breaks =c(0, 0.5, 1), position = "top")+
    geom_polygon(data = RangeBR, aes(x= long, y = lat, group = group), fill = NA, color= "grey50")+
    geom_map(data =  ggworldMap, map = ggworldMap, aes(long, lat, map_id = id), fill = "grey75")+
    coord_cartesian(xlim = c(11, 54.5), ylim = c(67.5, 77.5), expand = c(0, 0)) +
    theme_classic()+
    theme(strip.placement = "outside",
          strip.background.y = element_blank(),
          strip.text = element_text(size = 12, family="serif"),
          axis.title = element_blank(),
          text = element_text(size = 11, family="serif"),
          axis.text.x = element_text(size = 10),
          axis.text.y = element_text(size = 10, angle = 90, hjust = 0.5),
          axis.line = element_line(color = "grey70"),
          legend.title = element_text(size = 11),
          legend.text = element_text(size = 11),
          legend.position = "bottom",
          legend.spacing.x = unit(1.0, 'cm'),
          strip.background = element_rect(fill=NA, color=NA))+
    labs(fill = expression(frac(bar(Y)["a,s"],max((bar(Y)[a])))))+
    guides(fill = guide_colourbar(title.position="top", title.hjust = 0.5))+
    scale_x_continuous(breaks = ewbrks, labels = ewlbls, expand = c(0, 0)) +
    scale_y_continuous(breaks = nsbrks, labels = nslbls, expand = c(0, 0))+
    facet_grid(Species~Stage, switch = "y")
  
  
  #######################################################################
  #######################################################################
  #######################################################################
  
  sp<-1
  art<-usespecies.df[sp, 1]
  species<-usespecies.df[sp, 2]
  
  
  # Define age classes (The file sourced after will need it to extract the right ages range):
  acats<-1:8

  # LOADING DATA ####
  print("Getting density data for ages:")
  ylu<-ylu_list[[paste(species,Offs,sep = "_")]]
  
  YearsSampled<-rowSums(rowSums(ylu, dim = 2, na.rm = TRUE)) != 0
  AgeSampled<-rowSums(ylu, dims = 2, na.rm= TRUE)>0
  #AgeSampled<-AgeSampled[YearsSampled,]
  
  log.AG.ylu<-colMeans(ylu[,,1:8], dim = 1, na.rm= TRUE)
  log.AG.ylu<-sweep(log.AG.ylu, 2, apply(log.AG.ylu,2,max), `/`)
  log.AG.ylu.df<-melt(log.AG.ylu)
  colnames(log.AG.ylu.df)<-c("gridid", "Stage", "Density")
  #####################################################################
  e.ylu<-exp(ylu)-1        
  AG.ylu<-rowSums(e.ylu[YearsSampled,,9:max(acats)], dim =2)
  log.AG.ylu<-log(AG.ylu+1)
  log.AG.ylu[abs(log.AG.ylu)==Inf] <- NA 
  log.AG.ylu<-colMeans(log.AG.ylu, na.rm = TRUE)
  log.AG.ylu<-log.AG.ylu/max(log.AG.ylu, na.rm= TRUE)
  temp.ylu<-melt(log.AG.ylu)
  temp.ylu$gridid<-rownames(temp.ylu)
  colnames(temp.ylu)<-c("Density","gridid")
  temp.ylu$Stage<-"9+"
  log.AG.ylu.df<-rbind(log.AG.ylu.df, temp.ylu)
  log.AG.ylu.df$Species <-species
  
  ####################################################################
  
  sp<-2
  art<-usespecies.df[sp, 1]
  species<-usespecies.df[sp, 2]
  # Define age classes (The file sourced after will need it to extract the right ages range):

  
  # LOADING DATA ####
  print("Getting density data for ages:")
  ylu<-ylu_list[[paste(species,Offs,sep = "_")]]
  
  YearsSampled<-rowSums(rowSums(ylu, dim = 2, na.rm = TRUE)) != 0
  AgeSampled<-rowSums(ylu, dims = 2, na.rm= TRUE)>0
  
  log.AG.ylu<-colMeans(ylu[,,1:8], dim = 1, na.rm= TRUE)
  log.AG.ylu<-sweep(log.AG.ylu, 2, apply(log.AG.ylu,2,max), `/`)
  temp.ylu<-melt(log.AG.ylu)
  colnames(temp.ylu)<-c("gridid", "Stage", "Density")
  temp.ylu$Species <-species
  log.AG.ylu.df<-rbind(log.AG.ylu.df, temp.ylu)
  
  #####################################################################
  
  e.ylu<-exp(ylu)-1        
  AG.ylu<-rowSums(e.ylu[YearsSampled,,9:max(acats)], dim =2)
  log.AG.ylu<-log(AG.ylu+1)
  log.AG.ylu[abs(log.AG.ylu)==Inf] <- NA 
  log.AG.ylu<-colMeans(log.AG.ylu, na.rm = TRUE)
  log.AG.ylu<-log.AG.ylu/max(log.AG.ylu, na.rm= TRUE)
  temp.ylu<-melt(log.AG.ylu)
  temp.ylu$gridid<-rownames(temp.ylu)
  colnames(temp.ylu)<-c("Density","gridid")
  temp.ylu$Stage<-"9+"
  temp.ylu$Species <-species
  
  log.AG.ylu.df<-rbind(log.AG.ylu.df, temp.ylu)
  
  
  
  ####################################################################
  hex_grid_LL_df<-fortify(hex_grid_LL_M)
  hex_grid_LL_df<-merge(log.AG.ylu.df, hex_grid_LL_df, by.x = "gridid", by.y = "id")
  hex_grid_LL_df<-hex_grid_LL_df[order(hex_grid_LL_df$group, hex_grid_LL_df$order),]
  
  Range<-hex_grid_LL_M[unique(hex_grid_LL_df[!is.na(hex_grid_LL_df$Density),'gridid'])]
  Range<-fortify(aggregate(Range))
  
  AgessMap<-ggplot(hex_grid_LL_df[!is.na(hex_grid_LL_df$Density) & hex_grid_LL_df$Stage != "9+",], aes(long, lat))+
    geom_polygon(aes(fill = Density, group= group))+
    scale_fill_gradientn(colors = Pal)+
    geom_polygon(data = Range, aes(x= long, y = lat, group = group), fill = NA, color= "grey50")+
    geom_map(data =  ggworldMap, map = ggworldMap, aes(long, lat, map_id = id), fill = "grey55")+
    coord_cartesian(xlim = c(11, 54.5), ylim = c(67.5, 77.5), expand = c(0, 0)) +
    theme_classic()+
    theme(strip.placement = "outside",
          legend.position="none",
          strip.background.y = element_blank(),
          axis.title = element_blank(),
          text = element_text(size = 15, family="serif"),
          axis.text.x = element_text(size = 10),
          axis.text.y = element_text(size = 10, angle = 90, hjust = 0.5),
          axis.line = element_line(color = "grey70"),
          strip.background = element_rect(fill=NA, color=NA))+
    scale_x_continuous(breaks = ewbrks, labels = ewlbls, expand = c(0, 0)) +
    scale_y_continuous(breaks = nsbrks, labels = nslbls, expand = c(0, 0))+
    facet_grid(Species~Stage, switch = "y")
  
  
  
  legend<-as_ggplot(get_legend(BeakedStagesMap))+ theme(plot.margin = margin(0.2,0.1,0.2,0.1, "cm"))
  
  
  DensityMaps <-  ggarrange(AgessMap, ggarrange(BeakedStagesMap+theme(legend.position="none"), NULL,legend,NULL, ncol = 4, nrow = 1,  widths = c(1.4,0.5,0.6,1.45), heights = c(1)), labels = c("a)", "b)"), font.label = list(size = 12, family = "serif"),ncol = 1, nrow = 2,  widths = 1, heights = c(1.5,1.1))
  
  setwd("C:/Users/jonatanf/Documents/Chapter2/Figures/SynchronyFinal")
  

  
  ggsave(DensityMaps, file = paste("DensityMaps_",a,".tiff"),height= 9.78,width= 16.51,units="cm",dpi=1000,compression="lzw")
  