### FUNCTIONS AND PACKAGES ####
library("ggplot2")
library("dplyr")
library("reshape2")
library("mvtnorm")
library("furrr")
library("future")
Logit<-function(r)log(r/(1-r))
InvLogit<-function(z)exp(z)/(exp(z)+1)
options(dplyr.summarise.inform = FALSE)

future::plan(multiprocess)

# Correlation of time series with a minimum number of overlapping years
cor.overlap <- function(data, n = 3) {

  # Correlation
  cor.data <- cor(data, use="pairwise.complete.obs")
  diag(cor.data) <- NA

  # Calculate number of overlapping years between time series
  overlap <- matrix(NA, nrow=ncol(data), ncol=ncol(data))

  for(i in 1:ncol(data)) {
    for(j in 1:ncol(data)) {
      overlap[i, j] <- sum(complete.cases(data[,i], data[,j]))
    }
  }

  # Correlations set to NA if number of overlapping years between time series is below the threshold
  cor.data[overlap < n] <- NA

  # Melt
  output <- reshape2::melt(cor.data)

  return(list(Output=output, Overlap=overlap))
}

# Gaussian synchrony functions
par.boot <- function(data, zu ,rho.0, rho.inf, lambda, bt) {
  # bt: number of bootstrap replicates
  # rho.0: estimate for rho.0
  # rho.inf: estimate for rho.inf
  # lambda: estimate for lambda
  # start.val: starting values for optimizer
  # Parameters estimated by MLE model
  # bt<-100 
  # rho.0 <- X$rho.0 # estimate for rho.0
  # rho.inf <- X$rho.inf # estimate for rho.inf
  # lambda <- X$lambda # estimate for lambda
  
  #distmatsel <- test.distmati
  sigma <- (rho.0-rho.inf)*exp(-(zu^2)/(2*lambda^2)) + rho.inf
  diag(sigma) <- 1
  
  boot <- list()
  for(i in 1:bt){
    repb <- rmvnorm(nrow(data), rep(0, nrow(sigma)), sigma) 
    # Draw random numbers from multivariate normal distribution 
    # defined by rho.0, rho.inf and lambda
    repb[is.na(data)] <- NA # Remove values that are NA in original dataset
    boot[[i]] <- repb
  }
  return(boot)
  
}



####################################################################################################
####################################################################################################

lls<-function(pars,x,distmat){
  r0<-InvLogit(pars[1])
  #rInf<-InvLogit(pars[2])
  rInf<-InvLogit(pars[1])*InvLogit(pars[2])
  l<-exp(pars[3])
  #s2<-exp(pars[4])
  
  n<-nrow(x)
  if(n==1)x<-x-mean(x,na.rm=T)
  else x<-x-matrix(rep(colMeans(x,na.rm=T),n),ncol=nrow(distmat),byrow=T)
  
  ll<-0
  
  for(i in 1:n){
    xi<-x[i,]
    useid<-!is.na(xi)
    xiu<-xi[useid]
    distmatsel<-distmat[useid,useid]
    if(sum(useid)>2){
      mu <- rep(0, length(xiu))
      #sigma<-s2*(rInf+(r0-rInf)*exp(-distmatsel^2/(2*l^2)))
      sigma<-rInf+(r0-rInf)*exp(-distmatsel^2/(2*l^2))
      diag(sigma) <- 1
      
      ll <- ll + -sum(dmvnorm(xiu, mu, sigma,log = TRUE))
    }
  }
  ll
}

boot.nlminb <- function(x){
  f0<-nlminb(start.val,lls,x= x,distmat=zu.temp,lower=lower,upper=upper)
  #  f1S<-nlminb(c(Logit(.4),log(150),log(10)),lls0,x=t(colMeans(x,na.rm=T)),z=zu,lower=lower,upper=upper)
  partabs<-f0$par
  #partabs<-c(f0$par,f1S$par)
  
  names(partabs)<-c("logitrho0","logitrhoinf","logl")
  partabs<-partabs[c("logl","logitrho0","logitrhoinf")]
  partabs<-t(partabs)
  #pb$tick()$print()
  return(partabs)
}




lls2<-function(pars,x,distmat){
  r0<-InvLogit(pars[1])
  rInf<-InvLogit(pars[1])*InvLogit(pars[2])
  l<-exp(pars[3])
  
  ll<-0
  
  xi<-x
  useid<-!is.na(xi)
  xiu<-xi[useid]
  distmatsel<-distmat[useid,useid]
  if(sum(useid)>2){
    mu <- rep(0, length(xiu))
    sigma<-rInf+(r0-rInf)*exp(-distmatsel^2/(2*l^2))
    diag(sigma) <- 1
    
    ll <- ll + -sum(dmvnorm(xiu, mu, sigma,log = TRUE))
  }
  ll
}





substrRight <- function(x, n){
  substr(x, nchar(x)-n+1, nchar(x))
}

