### FUNCTIONS AND PACKAGES ####
library("ggplot2")
library("dplyr")
library("reshape2")
library("mvtnorm")
library("furrr")
library("future")
source("C:/Users/jonatanf/Documents/Chapter2/R.scripts/SI_Functions.R")



####  PARAMETERS AND DATA ####
#Set boundaries and starting values for autocorrelation estimation;
lower<-rep(-Inf,4)
upper<-rep(Inf,4)
lower[1:2]<--10
upper[1:2]<-10
start.val=c(Logit(.8),Logit(.0000000001),log(200))
usespecies.df<-data.frame(usespecies =c("HYSE", "SNABELUER", "TORSK"), usespeciesENG = c("Haddock", "B_redfish", "Cod"))

nboots<-500 # Number of bottstraps
yrs<-1985:2016
agegroups<-list("B_redfish"= c(1,11,64), "Haddock"= c(1,6,16), "Cod" = c(1, 7, 17))
StageName<-c("Juvenile", "Adult")

# Spatial resolution
a<-6400  
source("C:/Users/jonatanf/Documents/Chapter2/R.scripts/Hexagon.R")

setwd("C:/Users/jonatanf/Documents/Chapter2/R.scripts")
load(file = paste0("ylu_",a,"_list.rda"))
load(file = paste0("yu_",a,"_list.rda"))
load(file = paste0("zlu_",a,"_list.rda"))
load(file = paste0("zu_",a,"_list.rda"))

SynchResults<-data.frame()
SynchPoints<-data.frame()

for(sp in 1:3){
  for(Offs in seq(0, -3.5, -0.25)){
    
    
  art<-usespecies.df[sp, 1]
  species<-usespecies.df[sp, 2]
  
  
  
  # subset the data
  ylu<-ylu_list[[paste(species,Offs,sep = "_")]]
  yu<-yu_list[[paste(species,Offs,sep = "_")]]
  zlu<-zlu_list[[paste(species,Offs,sep = "_")]]
  zu<-zu_list[[paste(species,Offs,sep = "_")]]
  
  YearsSampled<-rowSums(rowSums(ylu, dim = 2, na.rm = TRUE)) != 0
  
  #-------------------------------------####
  #-------------------------------------####
  #POPULATION
  cat("Synchrony of population\n")
  e.yu<-exp(yu)-1
  log.yu<-log(e.yu+1)
  
  log.yu<-log.yu[YearsSampled,]
  
  log.yu[abs(log.yu)==Inf] <- NA 
  scaled.log.yu<-scale(log.yu)
  
  SynchPoints.temp<-cor.overlap(scale(log.yu))
  SynchPoints.temp<-merge(SynchPoints.temp$Output, melt(zu), by = c("Var1", "Var2"))
  colnames(SynchPoints.temp)<-c("From", "To", "rho", "Distance")
  SynchPoints<-rbind(SynchPoints, data.frame(SynchPoints.temp, Species = species, Stage = "Population", Resolution = a, Offset = Offs))
  

  zu.temp<-zu
  

  cat("\n")
  #-------------------------------------####
  # Autocorrelation
  outputv<-nlminb(start.val[1:3],lls, x=scaled.log.yu, distmat=zu.temp, lower=lower,upper=upper)
  parsV <- data.frame(rho.0=exp(outputv$par[1])/(1+exp(outputv$par[1])),
                      rho.inf=exp(outputv$par[1])/(1+exp(outputv$par[1]))* exp(outputv$par[2])/(1+exp(outputv$par[2])),
                      lambda=exp(outputv$par[3]))
  
  # Bootstrapping
  Boots.yu<-par.boot(data = scaled.log.yu, zu.temp, rho.0= parsV$rho.0,  rho.inf= parsV$rho.inf, lambda= parsV$lambda, bt= nboots)
  cat("\n")
  
  tempV <- furrr::future_map(Boots.yu, function(x) boot.nlminb(x), .progress = TRUE)
  
# Storing
    SynchResults.temp <- rbind(data.frame(do.call(rbind, tempV), Method = "nlminb", Species = species, Stage = "Population", Offset = Offs, Resolution = a))

  SynchResults<-rbind(SynchResults, SynchResults.temp)
  
  #-------------------------------------####
  #-------------------------------------####
  # LIFE STAGES
    e.ylu<-exp(ylu)-1

  YearsSampled<-rowSums(rowSums(ylu, dim = 2, na.rm = TRUE)) != 0
  if(sp == 2){Sampled<-rowSums(ylu, dims = 2, na.rm= TRUE)>0}else{Sampled<-!is.na(rowSums(ylu, dims = 2, na.rm= FALSE))} # Beaked redfish is wrongly marked as 0 in years when it wasnt sampled for age.  
  
   Stages.Labels<-c() 
  Stages.DF<-data.frame()
  for(stage.temp in 1:2){
    Stages.Labels<-c(Stages.Labels, paste(agegroups[[paste(species)]][stage.temp],"-",(agegroups[[paste(species)]][stage.temp+1]-1), sep= ""))
    Stages.DF<-rbind(Stages.DF, data.frame(from= agegroups[[paste(species)]][stage.temp], to = (agegroups[[paste(species)]][stage.temp+1]-1)))
  } #// agroup
  
  for(stage.temp in 1:2){
    cat("\nSynchrony of stage", Stages.Labels[stage.temp],"\n")
    
    Stage.ylu<-rowSums(e.ylu[YearsSampled,,Stages.DF[stage.temp,1]:Stages.DF[stage.temp,2]], dim =2, na.rm= TRUE)
    
   
    Sampled.temp<-Sampled[rownames(Stage.ylu),]
    
    Stage.ylu<-ifelse(Sampled.temp == FALSE, NA, Stage.ylu)
    
    log.Stage.ylu<-log(Stage.ylu+1)
    log.Stage.ylu[abs(log.Stage.ylu)==Inf] <- NA 
    log.Stage.ylu<-scale(log.Stage.ylu)
    
    SynchPoints.temp<-cor.overlap(scale(log.Stage.ylu))
    SynchPoints.temp<-merge(SynchPoints.temp$Output, melt(zlu[,,1]), by = c("Var1", "Var2"))
    colnames(SynchPoints.temp)<-c("From", "To", "rho", "Distance")
    
    SynchPoints<-rbind(SynchPoints, data.frame(SynchPoints.temp, Species = species, Stage = Stages.Labels[stage.temp], Resolution = a, Offset = Offs))
  
    zu.temp<-zlu[,,1]
    
    #-------------------------------------####
    # Autocorrelation
    outputv<-nlminb(start.val,lls, x=log.Stage.ylu, distmat=zu.temp, lower=lower,upper=upper)
    
    parsV <- data.frame(rho.0=exp(outputv$par[1])/(1+exp(outputv$par[1])), 
                        rho.inf=exp(outputv$par[1])/(1+exp(outputv$par[1]))* exp(outputv$par[2])/(1+exp(outputv$par[2])), 
                        lambda=exp(outputv$par[3]))
    # Bootstrapping
    Boots.yu<-par.boot(data = log.Stage.ylu, zu.temp, rho.0= parsV$rho.0,  rho.inf= parsV$rho.inf, lambda= parsV$lambda, bt= nboots)
    pb <- dplyr::progress_estimated(nboots) # Timer
    tempV <- furrr::future_map(Boots.yu, function(x) boot.nlminb(x), .progress = TRUE)
    
    cat("\n")
    
    # Storing
      SynchResults.temp <- rbind(data.frame(do.call(rbind, tempV), Method = "nlminb", Species = species, Stage = Stages.Labels[stage.temp], Offset = Offs, Resolution = a))
      SynchResults<-rbind(SynchResults, SynchResults.temp)

    
  }#//Stage
}#//Offs

}#//Species
#ave(SynchResults, file = "SI.SynchResults.rda")

#Backtranforming autocorrelation estimates
SynchResults$logitrhoinf <- InvLogit(SynchResults$logitrho0)*InvLogit(SynchResults$logitrhoinf)
SynchResults$logitrho0 <- InvLogit(SynchResults$logitrho0)
SynchResults$logl <- exp(SynchResults$logl)


# #Rename stages
SynchResults[SynchResults$Species == "B_redfish", 'Species']<-"Beaked redfish"
SynchResults[SynchResults$Stage %in% c("1-10", "1-5","1-6"), 'Stage2']<-"Juvenile"
SynchResults[SynchResults$Stage %in% c("11-63", "6-15", "7-16"), 'Stage2']<-"Adult"
SynchResults[SynchResults$Stage == "Population", 'Stage2']<-"Population"

Values<-SynchResults %>%
  filter(Resolution ==6400) %>%
  dplyr::group_by(Stage2, Species, Resolution) %>%
  dplyr::summarise(L.mean = median(logl),
                   L.975 = quantile(logl, 0.975),
                   L.025 = quantile(logl, 0.025),
                   R0.mean = median(logitrho0 ),
                   R0.975 = quantile(logitrho0 , 0.975),
                   R0.025 = quantile(logitrho0 , 0.025),
                   Rinf.mean = median(logitrhoinf ),
                   Rinf.975 = quantile(logitrhoinf , 0.975),
                   Rinf.025 = quantile(logitrhoinf , 0.025)) %>%
  as.data.frame()
write.csv(Values[order(Values$Resolution, Values$Species, Values$Stage2), ], file = "StagesSynchValues.csv") 

# Estimating values to plot ribbon
SynchRibbon<-data.frame()
for(d in seq(0, 1200, 10)){
  temp.sp<-data.frame(RhoAt=SynchResults$logitrhoinf -(SynchResults$logitrhoinf -SynchResults$logitrho0)*exp(-d^2/(2*SynchResults$logl^2)), Method= SynchResults$Method, Species = SynchResults$Species, Stage=SynchResults$Stage, Offset =SynchResults$Offset, Resolution = SynchResults$Resolution, Stage2=SynchResults$Stage2) 
  # Get mediana and 95% ConfInt
  temp.rho<- temp.sp %>%
    dplyr::group_by(Method, Species, Stage, Resolution, Stage2)%>%#, Offset)%>%
    dplyr::summarise(Q2.5 = quantile(RhoAt, 0.025),
                     Q5 = quantile(RhoAt, 0.05),
                     Q97.5 = quantile(RhoAt, 0.975),
                     Q95 = quantile(RhoAt, 0.95),
                     M = median(RhoAt))%>%
    as.data.frame()
  
  SynchRibbon<-rbind(SynchRibbon, data.frame(temp.rho, Distance = d))
}  # // Ribbon loop 

MaxRange<-SynchPoints %>%
  filter(!is.na(rho))%>%
  dplyr::group_by(Species, Stage, Resolution, Offset) %>%
  dplyr::summarise(Extent = max(Distance))%>%
  as.data.frame()
MaxRange[MaxRange$Species == "B_redfish", 'Species']<-"Beaked redfish"


SynchRibbon <- SynchRibbon %>%
  dplyr::left_join(MaxRange[,-4], by = c("Species", "Stage", "Resolution")) %>%
  dplyr::filter(Distance <= Extent)



SynchRibbon$Species<-factor(SynchRibbon$Species, levels= c("Cod", "Haddock","Beaked redfish"))

setwd("C:/Users/jonatanf/Documents/Chapter2/Figures/SynchronyFinal")


  ThePlot <- 
    ggplot(SynchRibbon[SynchRibbon$Resolution == a ,], aes(Distance, M))+
    geom_ribbon(aes(ymin=Q2.5, ymax=Q97.5, x = Distance, fill = as.factor(Stage2)), alpha = 0.3)+
    geom_line(aes(color = as.factor(Stage2), linetype= as.factor(Stage2)))+
    theme_classic()+
    coord_cartesian(ylim = c(-0.01,1), xlim = c(-10,1200), expand = c(0, 0))+ 
    geom_hline(yintercept = 0, color = "grey") + 
    geom_vline(xintercept = 0, color = "grey") + 
    facet_grid( ~ Species)+

    scale_fill_manual(values = c( "#34A0A4", "#184E77","#B5E48C"), name = "Life stage:")+
    scale_color_manual(values = c(  "#219ebc", "#023047","#81b29a"), name = "Life stage:")+
    scale_linetype_manual(values = c(3,2,1), name = "Life stage:")+
    labs(y = expression(rho), x = "Distance (km)")+
    theme(strip.placement = "inside",
          strip.background.y = element_blank(), 
          strip.background = element_rect(fill=NA, color=NA),
          strip.text.x = element_text(size = 12),
          legend.position="bottom",
          legend.text = element_text(size = 12, color = "grey10"),
          legend.title = element_text(size = 12, color = "grey10"),
          text = element_text(family="serif"),
          panel.grid.major = element_blank(),
          panel.grid.minor =  element_blank(),
          axis.line = element_blank(),
          axis.ticks = element_line(color = "grey20"),
          axis.ticks.length=unit(0.15, "cm"),  
          axis.title.x = element_text(size = 11, color="grey10", margin = margin(t = 5, r = 0, b = 0, l = 0)),   
          axis.text.x = element_text(size = 11,color="grey40"),   
          axis.title.y = element_text(size = 12, color="black", angle = 0, vjust = 0.5, margin = margin(t = 0, r = 8, b = 0, l = 0)),   
          axis.text.y = element_text(size = 11,color="grey40"),   
          panel.spacing.x = unit(10, "mm"),
          plot.margin = margin(0,0.5,0,0, "cm")) 
  

  
  ggsave(ThePlot, file = paste0("Synchronies.",a,".tiff"),height= 7.78,width= 16.51,units="cm",dpi=1200,compression="lzw")
  
  

# # OTHER RESOLUTIONS FORMATTED FOR THE APPENDIX
# 
# my_labeller <- as_labeller(c("2500"="2500~km^2", "3600"="3600~km^2", "4900"="4900~km^2", "6400"="6400~km^2"),
#                            default = label_parsed)
# 
# 
# ThePlot <- 
#   ggplot(SynchRibbon[SynchRibbon$Resolution %in% unique(SynchRibbon$Resolution)[1:4] ,], aes(Distance, M))+
#   geom_ribbon(aes(ymin=Q2.5, ymax=Q97.5, x = Distance, fill = as.factor(Stage)),alpha = 0.2)+
#   geom_line(aes(color = as.factor(Stage), linetype= as.factor(Stage)))+
#   theme_classic()+
#   coord_cartesian(ylim = c(-0.01,1), xlim = c(-10,1200), expand = c(0, 0))+ 
#   geom_hline(yintercept = 0, color = "grey") + 
#   geom_vline(xintercept = 0, color = "grey") + 
#   facet_grid(Resolution ~ Species, labeller = my_labeller)+
#   scale_fill_manual(values = c("#184e77",   "#34A0A4", "#BF6900"), name = "Life stage:")+
#   scale_color_manual(values = c("#184e77" ,   "#34A0A4", "#A37D00" ), name = "Life stage:")+
#   scale_linetype_manual(values = c(3,2,1), name = "Life stage:")+
#   labs(y = expression(rho), x = "Distance (km)")+
#   theme(strip.placement = "inside",
#         strip.background.y = element_blank(), 
#         strip.background = element_rect(fill=NA, color=NA),
#         strip.text.x = element_text(size = 12),
#         legend.position="bottom",
#         legend.text = element_text(size = 12, color = "grey10"),
#         legend.title = element_text(size = 12, color = "grey10"),
#         text = element_text(family="serif"),
#         panel.grid.major = element_blank(),
#         panel.grid.minor =  element_blank(),
#         axis.line = element_blank(),
#         axis.ticks = element_line(color = "grey20"),
#         axis.ticks.length=unit(0.15, "cm"),  
#         axis.title.x = element_text(size = 11, color="grey10", margin = margin(t = 5, r = 0, b = 0, l = 0)),   
#         axis.text.x = element_text(size = 11,color="grey40"),   
#         axis.title.y = element_text(size = 12, color="black", angle = 0, vjust = 0.5, margin = margin(t = 0, r = 8, b = 0, l = 0)),   
#         axis.text.y = element_text(size = 11,color="grey40"),   
#         panel.spacing = unit(10, "mm"),
#         plot.margin = margin(0,0.5,0,0, "cm"))
# 
# 
# ggsave(ThePlot, file = paste0("Synchronies.Appendix_50-80.tiff"),height= 20,width= 16.51,units="cm",dpi=1200,compression="lzw")
# 
# 
# my_labeller <- as_labeller(c("8100"="8100~km^2", "10000"="10000~km^2", "12100"="12100~km^2"),
#                            default = label_parsed)
# 
# ThePlot <- 
#   ggplot(SynchRibbon[SynchRibbon$Resolution %in% unique(SynchRibbon$Resolution)[5:7] ,], aes(Distance, M))+
#   geom_ribbon(aes(ymin=Q2.5, ymax=Q97.5, x = Distance, fill = as.factor(Stage)),alpha = 0.2)+
#   geom_line(aes(color = as.factor(Stage), linetype= as.factor(Stage)))+
#   theme_classic()+
#   coord_cartesian(ylim = c(-0.01,1), xlim = c(-10,1200), expand = c(0, 0))+ 
#   geom_hline(yintercept = 0, color = "grey") + 
#   geom_vline(xintercept = 0, color = "grey") + 
#   facet_grid(Resolution ~ Species, labeller = my_labeller)+    
#   scale_fill_manual(values = c("#184e77",   "#34A0A4", "#BF6900"), name = "Life stage:")+
#   scale_color_manual(values = c("#184e77" ,   "#34A0A4", "#A37D00" ), name = "Life stage:")+
#   scale_linetype_manual(values = c(3,2,1), name = "Life stage:")+
#   labs(y = expression(rho), x = "Distance (km)")+
#   theme(strip.placement = "inside",
#         strip.background.y = element_blank(), 
#         strip.background = element_rect(fill=NA, color=NA),
#         strip.text.x = element_text(size = 12),
#         legend.position="bottom",
#         legend.text = element_text(size = 12, color = "grey10"),
#         legend.title = element_text(size = 12, color = "grey10"),
#         text = element_text(family="serif"),
#         panel.grid.major = element_blank(),
#         panel.grid.minor =  element_blank(),
#         axis.line = element_blank(),
#         axis.ticks = element_line(color = "grey20"),
#         axis.ticks.length=unit(0.15, "cm"),  
#         axis.title.x = element_text(size = 11, color="grey10", margin = margin(t = 5, r = 0, b = 0, l = 0)),   
#         axis.text.x = element_text(size = 11,color="grey40"),   
#         axis.title.y = element_text(size = 12, color="black", angle = 0, vjust = 0.5, margin = margin(t = 0, r = 8, b = 0, l = 0)),   
#         axis.text.y = element_text(size = 11,color="grey40"),   
#         panel.spacing = unit(10, "mm"),
#         plot.margin = margin(0,0.5,0,0, "cm"))
# 
# 
# 
# ggsave(ThePlot, file = paste0("Synchronies.Appendix_90-110.tiff"),height= 15,width= 16.51,units="cm",dpi=1200,compression="lzw")
# 
# 
# ##########################################




