### FUNCTIONS AND PACKAGES ####
library("ggplot2")
library("dplyr")
library("reshape2")
library("mvtnorm")
library("furrr")
library("future")
library("ggridges")
library("tidyr")
library(ggpubr)
source("C:/Users/jonatanf/Documents/Chapter2/R.scripts/SI_Functions.R")
library("overlapping")
library(modeest)
#############################################################################

####  PARAMETERS AND DATA ####

#Set boundaries for parameter values; only occasionally needed
lower<-rep(-Inf,4)
upper<-rep(Inf,4)
lower[1:2]<--10
upper[1:2]<-10
start.val=c(Logit(.8),Logit(.000000001),log(200))
usespecies.df<-data.frame(usespecies =c("HYSE", "SNABELUER", "TORSK"), usespeciesENG = c("Haddock", "B_redfish", "Cod"))

nboots<-500
yrs<-1985:2016
agegroups<-list("B_redfish"= c(1,11,64), "Haddock"= c(1,6,16), "Cod" = c(1, 7, 17))

SynchResults<-data.frame()
SynchPoints<-data.frame()
#for(a in av{
a<-6400 


setwd("C:/Users/jonatanf/Documents/Chapter2/R.scripts")
load(file = paste0("ylu_",a,"_list.rda"))
load(file = paste0("zlu_",a,"_list.rda"))

SynchResults<-data.frame()
SynchPoints<-data.frame()

for(sp in c(1,3)){
  for(Offs in seq(0, -3.5, -0.25)){
    
    art<-usespecies.df[sp, 1]
    species<-usespecies.df[sp, 2]
    
    cat(paste(species))
    
    ylu<-ylu_list[[paste(species,Offs,sep = "_")]]
    zlu<-zlu_list[[paste(species,Offs,sep = "_")]]
    
    # AGES
    e.ylu<-exp(ylu)-1
    
    YearsSampled<-rowSums(rowSums(e.ylu, dim = 2, na.rm = TRUE)) != 0
    Sampled<-!is.na(rowSums(e.ylu, dims = 2, na.rm= FALSE))
    
    
    for(age.temp in 1:8){
      cat("\nSynchrony of age", age.temp,"\n")
      
      
      Age.ylu<-e.ylu[YearsSampled,,age.temp]
      Sampled.temp<-Sampled[rownames(Age.ylu),]
      
      Age.ylu<-ifelse(Sampled.temp == FALSE, NA, Age.ylu)
      
      log.Age.ylu<-log(Age.ylu+1)
      log.Age.ylu[abs(log.Age.ylu)==Inf] <- NA 
      log.Age.ylu<-scale(log.Age.ylu)
      
      zu.temp<-zlu[,,1][rownames(zlu[,,1]) %in% colnames(log.Age.ylu), colnames(zlu[,,1]) %in% colnames(log.Age.ylu)]
      
      log.Age.ylu<-log.Age.ylu[,colnames(zu.temp)]
      
      SynchPoints.temp<-cor.overlap(scale(log.Age.ylu))
      SynchPoints.temp<-merge(SynchPoints.temp$Output, melt(zu.temp), by = c("Var1", "Var2"))
      colnames(SynchPoints.temp)<-c("From", "To", "rho", "Distance")
      SynchPoints<-rbind(SynchPoints, data.frame(SynchPoints.temp, Species = species, Stage = paste(age.temp), Resolution = a, Offset = Offs, Data = "Density"))
      
      cat("\n")
      cat("Density")
      outputv<-nlminb(start.val,lls, x=log.Age.ylu, distmat=zu.temp, lower=lower,upper=upper)
      
      parsV <- data.frame(rho.0=exp(outputv$par[1])/(1+exp(outputv$par[1])),
                          rho.inf=exp(outputv$par[1])/(1+exp(outputv$par[1]))* exp(outputv$par[2])/(1+exp(outputv$par[2])),
                          lambda=exp(outputv$par[3]))
      Boots.yu<-par.boot(data = log.Age.ylu, zu.temp, rho.0= parsV$rho.0,  rho.inf= parsV$rho.inf, lambda= parsV$lambda, bt= nboots)
      tempV <- furrr::future_map(Boots.yu, function(x) boot.nlminb(x), .progress = TRUE)
      
      SynchResults.temp <- data.frame(do.call(rbind, tempV), Method = "nlminb", Species = species, Stage = age.temp, Offset = Offs, Data = "Density", Resolution = a)
      
      SynchResults<-rbind(SynchResults, SynchResults.temp)
      
      #
      # Cohort independent density
      ##################################################################################################################################
      if(age.temp %in% c(1)){next()}
      
      # Estimating cohort dynamics
      DenAge.ylu<-melt(e.ylu[YearsSampled,,age.temp])
      colnames(DenAge.ylu)<-c("Year", "Site", "Density")
      
      temp.DenAge.ylu<-melt(e.ylu[YearsSampled,,(age.temp-1)])
      colnames(temp.DenAge.ylu)<-c("Year", "Site", "B4.Density")
      temp.DenAge.ylu$Year<-temp.DenAge.ylu$Year+1
      
      DenAge.ylu<-merge(DenAge.ylu, temp.DenAge.ylu, by = c("Year", "Site"), all.x= TRUE)
      
      DenAge.ylu<-DenAge.ylu[!is.na(DenAge.ylu$B4.Density) & !is.na(DenAge.ylu$Density),]
      
      DenAge.ylu$Density <- log(DenAge.ylu$Density+1)
      DenAge.ylu$B4.Density <- log(DenAge.ylu$B4.Density+1)
      
      model<-glm(Density ~ as.factor(Site) * B4.Density, data = DenAge.ylu, family=gaussian())
      DenAge.ylu$Residuals<-residuals(model)
      DenAge.ylu<-acast(DenAge.ylu, Year ~ Site, value.var= "Residuals")
      DenAge.ylu<-scale(DenAge.ylu)
      
      zu.temp<-zlu[,,1][rownames(zlu[,,1]) %in% colnames(DenAge.ylu), colnames(zlu[,,1]) %in% colnames(DenAge.ylu)]
      
      DenAge.ylu<-DenAge.ylu[,colnames(zu.temp)]
      
      SynchPoints.temp<-cor.overlap(scale(log.Age.ylu))
      SynchPoints.temp<-merge(SynchPoints.temp$Output, melt(zu.temp), by = c("Var1", "Var2"))
      colnames(SynchPoints.temp)<-c("From", "To", "rho", "Distance")
      SynchPoints<-rbind(SynchPoints, data.frame(SynchPoints.temp, Species = species, Stage = paste(age.temp), Resolution = a, Offset = Offs, Data = "Cohort-Independent"))
      
      cat("\n")
      cat("Cohort independent density")
      
      # Autocorrelation 
      outputv<-nlminb(start.val,lls, x=DenAge.ylu, distmat=zu.temp, lower=lower,upper=upper)
      
      parsV <- data.frame(rho.0=exp(outputv$par[1])/(1+exp(outputv$par[1])), 
                          rho.inf=exp(outputv$par[1])/(1+exp(outputv$par[1]))* exp(outputv$par[2])/(1+exp(outputv$par[2])), 
                          lambda=exp(outputv$par[3]))
      # Bootstrapping
      Boots.yu<-par.boot(data = DenAge.ylu, zu.temp, rho.0= parsV$rho.0,  rho.inf= parsV$rho.inf, lambda= parsV$lambda, bt= nboots)
      pb <- dplyr::progress_estimated(nboots) # Timer
      tempV <- furrr::future_map(Boots.yu, function(x) boot.nlminb(x), .progress = TRUE)
      
      # Storing
      cat("\n")
      SynchResults.temp <- data.frame(do.call(rbind, tempV), Method = "nlminb", Species = species, Stage = age.temp, Offset = Offs, Data = "Noise", Resolution = a)     
      
      SynchResults<-rbind(SynchResults, SynchResults.temp)
      
    }#//Ages
  }#//Species
}#//Offs
#save(SynchResults, file = "SI.SynchResults.Ages.rda")

SynchResults$logitrhoinf <- InvLogit(SynchResults$logitrho0)*InvLogit(SynchResults$logitrhoinf)
SynchResults$logitrho0 <- InvLogit(SynchResults$logitrho0)
SynchResults$logl <- exp(SynchResults$logl)

###############################################################################################################
###############################################################################################################
#               Estimating effect of cohort dynamics on density
###############################################################################################################
###############################################################################################################
Values<-SynchResults %>%
  dplyr::filter(Resolution == 6400) %>%
  dplyr::group_by(Stage, Species, Resolution, Data) %>%
  dplyr::summarise(L.mode = mlv(logl),
                   L.median = median(logl),
                   L.mean = mean(logl),
                   L.975 = quantile(logl, 0.975),
                   L.025 = quantile(logl, 0.025),
                   R0.mean = median(logitrho0 ),
                   R0.975 = quantile(logitrho0 , 0.975),
                   R0.025 = quantile(logitrho0 , 0.025),
                   Rinf.mean = median(logitrhoinf ),
                   Rinf.975 = quantile(logitrhoinf , 0.975),
                   Rinf.025 = quantile(logitrhoinf , 0.025))%>%
  as.data.frame()
write.csv(Values[order(Values$Resolution, Values$Species, Values$Stage, Values$Data), ], file = "AgesSynchValues.csv") 

setwd("C:/Users/jonatanf/Documents/Chapter2/Figures/SynchronyFinal")
#for(a in unique(SynchResults[SynchResults$Data =="Noise", 'Resolution'])){
 
  SynchResults_temp<-SynchResults
  
  MaxRanges<-SynchPoints%>%group_by(Species, Stage)%>% filter(!is.na(rho)) %>%summarise(Range = max(Distance, na.rm = TRUE))%>%as.data.frame()
  colnames(MaxRanges)[2]<-"Age"
  
  
  Diffs_df<-data.frame()
  for(i in 2:8){
    
    Temp_df<-Values[Values$Resolution == a & Values$Stage == i & Values$Species == "Cod" ,]
    Diffs_df<- rbind(Diffs_df, data.frame(Species = "Cod", Stage = i, Temp_df[Temp_df$Data == 'Noise', c('L.mode', 'L.median','L.mean', 'R0.mean', 'Rinf.mean')] - Temp_df[Temp_df$Data == 'Density', c('L.mode', 'L.median', 'L.mean', 'R0.mean', 'Rinf.mean')]))
    
    Temp_df<-Values[Values$Resolution == a & Values$Stage == i & Values$Species == "Haddock" ,]
    Diffs_df<- rbind(Diffs_df, data.frame(Species = "Haddock", Stage = i, Temp_df[Temp_df$Data == 'Noise', c('L.mode', 'L.median','L.mean', 'R0.mean', 'Rinf.mean')] - Temp_df[Temp_df$Data == 'Density', c('L.mode', 'L.median','L.mean', 'R0.mean', 'Rinf.mean')]))
    
  }
  
  
  Plot1<-ggplot(Diffs_df, aes(Stage, L.mode))+
    geom_point() +
    geom_line()+
    facet_grid(~Species)+
    geom_hline(yintercept = 0, linetype = "dashed")+
    coord_cartesian(ylim = c(-50, 215))+ 
    theme_classic()+
    scale_x_continuous(breaks = 1:8, expand = c(0, 0), limits = c(1.8, 8.2)) +
    geom_vline(xintercept = 1.8)+
    theme(axis.title.x =  element_blank(), 
          axis.text.x =  element_blank(),panel.grid.major.y = element_line(colour = "grey80"),
          text=element_text(family="helvetica"))+
    ylab(expression(paste(italic("l")," (km)")))

  Plot2<-ggplot(Diffs_df, aes(Stage, R0.mean))+geom_point()+geom_line()+
    facet_grid(~Species)+
    geom_hline(yintercept = 0, linetype = "dashed")+ theme_classic2()+
    scale_x_continuous(breaks = 1:8, expand = c(0, 0), limits = c(1.8, 8.2)) +
    geom_vline(xintercept = 1.8)+
    theme(axis.title.x =  element_blank(), 
          axis.text.x =  element_blank(),
          strip.background = element_blank(),
          strip.text.x = element_blank(),
          panel.grid.major.x = element_blank(),
          panel.grid.minor.x = element_blank(), 
          panel.grid.minor.y = element_blank(),
          panel.grid.major.y = element_line(colour = "grey80"),
          text=element_text(family="helvetica"))+
    ylab(expression(paste(italic(rho)["0"])))
  
  Plot3<-ggplot(Diffs_df, aes(Stage, Rinf.mean))+
    geom_point()+   
    geom_line()+
    facet_grid(~Species)+geom_hline(yintercept = 0, linetype = "dashed")+ 
    theme_classic()+ylab(expression(paste(italic(rho)[infinity, ])))+
    geom_vline(xintercept = 1.8)+
    scale_x_continuous(breaks = 1:8, expand = c(0, 0), limits = c(1.8, 8.2)) +
    xlab("Age")+
    theme(strip.background = element_blank(),
          strip.text.x = element_blank(),
          panel.grid.major.x = element_blank(),
          panel.grid.minor.x = element_blank(), 
          panel.grid.minor.y = element_blank(),
          panel.grid.major.y = element_line(colour = "grey80"),
          text=element_text(family="helvetica"))
  

  Plot<-ggarrange(Plot1, Plot2, Plot3, ncol = 1, align = "v", heights = c(2,1,1.3), labels = c("a)", "b)", "c)"), font.label = list(size = 10, family = "helvetica"))
  Plot<-annotate_figure(Plot, left = text_grob("Change in parameter after\n accounting for local-cohort dynamics", rot = 90, family = "helvetica", size = 10))
  ggsave(Plot, file = paste("SynchronyDifferences_",a,".tiff"),height= 8.78,width= 8.51,units="cm",dpi=800,compression="lzw")
  
  
  ###############################################################################################################
  ###############################################################################################################
  #               RIDGES
  ###############################################################################################################
  ###############################################################################################################
  SynchResults_temp$Parameter<-" italic(l) "
  SynchResults_temp$Parameter2<-" rho[0]"
  SynchResults_temp$Parameter3<-" rho[infinity]"
  
  
  ColorsData <- c("#00b4d8", "#1e6091")
  colnames(Values)[1]<-"Age"
  
  Height<-1.2
  
  scalingplotCod<- 
    ggplot(SynchResults_temp[SynchResults_temp$Stage<9 & SynchResults_temp$Species == "Cod",], aes(logl, as.factor(Stage)))+
    geom_density_ridges(aes(fill = Data), color =NA, rel_min_height = 0.001, alpha = 0.2,scale = Height, quantile_lines = TRUE, quantiles = 2, bandwidth = 0.5, size = 0.3)+
    geom_density_ridges(aes(color = Data), fill = NA, rel_min_height = 0.001,  scale =Height ,quantile_lines = TRUE, quantiles = 2, bandwidth = 0.5, size = 0.3)+
    theme_bw()+
    labs(x = "l (km)", y = "Age")+
    coord_cartesian(xlim = c(-50,500))+
    scale_x_continuous(limits =c(-30, 1201), expand = c(0, 0))+
    scale_y_discrete(expand = expand_scale(mult = c(0.01, 0.17))) +
    theme_ridges(center_axis_labels = TRUE)+
    theme(legend.position="none",
          strip.placement = "outside",
          strip.background.y = element_blank(), 
          strip.text.y = element_blank(),
          panel.grid.major.y = element_line(size = 0.0001, linetype = 'solid', colour = "grey85"),
          panel.grid.major.x = element_blank(),
          strip.background = element_rect(fill=NA, color="grey50",linetype="solid"),
          axis.ticks = element_line(color = "black"),
          axis.ticks.length=unit(0.15, "cm"),  
          axis.title.x = element_blank(),   
          axis.text.x = element_blank(),   
          axis.title.y = element_text(color="grey10", size = 9, margin = margin(t = 0, r = 8, b = 0, l = 0)),   
          axis.text.y = element_text(color="grey40", size = 9),   
          panel.spacing.y = unit(10, "mm"),
          text=element_text(family="helvetica"))+
    scale_fill_manual(values = ColorsData, labels = c("Density",  "Cohort-independent density"), name = "Variable")+
    scale_color_manual(values = ColorsData, labels = c("Density",  "Cohort-independent density"), name = "Variable")
  
  
  rho0plotCod<-
    ggplot(SynchResults_temp[SynchResults_temp$Stage<9 & SynchResults_temp$Species == "Cod",], aes(logitrho0, as.factor(Stage)))+
    geom_density_ridges(aes(fill = Data), color =NA, rel_min_height = 0.001, alpha = 0.2,scale = Height, quantile_lines = TRUE, quantiles = 2, bandwidth = 0.01, size = 0.3)+
    geom_density_ridges(aes(color = Data), fill = NA, rel_min_height = 0.001, bins = 100, scale = Height,quantile_lines = TRUE, quantiles = 2, bandwidth = 0.01, size = 0.3)+
    theme_bw()+
    labs(x = expression(rho[0]), y = "Age")+
    coord_cartesian(xlim = c(0,1))+
    scale_x_continuous(limits =c(0, 1), expand = c(0, 0))+
    scale_y_discrete(expand = expand_scale(mult = c(0.01, 0.17))) +
    theme_ridges(center_axis_labels = TRUE)+
    theme(legend.position="none",
      strip.placement = "outside",
      strip.background.y = element_blank(), 
      strip.text.y = element_blank(),
      panel.grid.major.y = element_line(size = 0.0001, linetype = 'solid', colour = "grey85"),
      panel.grid.major.x = element_blank(),
      strip.background = element_rect(fill=NA, color="grey50",linetype="solid"),
      axis.ticks = element_line(color = "black"),
      axis.ticks.length=unit(0.15, "cm"),  
      axis.title.x = element_blank(),   
      axis.text.x = element_blank(), 
      axis.title.y = element_blank(),   
      axis.text.y = element_text(color=NA), 
      panel.spacing.y = unit(10, "mm"),
      text=element_text(family="helvetica"))+
    scale_fill_manual(values = ColorsData, labels = c("Density",  "Cohort-independent density"), name = "")+
    scale_color_manual(values = ColorsData, labels = c("Density",  "Cohort-independent density"), name = "")
  

  rhoInfplotCod<-
    ggplot(SynchResults_temp[SynchResults_temp$Stage<9 & SynchResults_temp$Species == "Cod",], aes(logitrhoinf, as.factor(Stage)))+
    geom_density_ridges(aes(fill = Data), color =NA, rel_min_height = 0.001, alpha = 0.2,scale = 1.1, quantile_lines = TRUE, quantiles = 2, bandwidth = 0.01, size = 0.3)+
    geom_density_ridges(aes(color = Data), fill = NA, rel_min_height = 0.001, bins = 100, scale = 1.1,quantile_lines = TRUE, quantiles = 2, bandwidth = 0.01, size = 0.3)+
    theme_bw()+
    labs(x = expression(rho[infinity]), y = "Age")+
    coord_cartesian(xlim = c(0,1))+
    scale_x_continuous(limits =c(0, 1), expand = c(0, 0))+
    scale_y_discrete(expand = expand_scale(mult = c(0.01, 0.17))) +
    theme_ridges(center_axis_labels = TRUE)+
    theme(legend.position="none",
      strip.placement = "outside",
      strip.background.y = element_blank(), 
      strip.text.y = element_blank(),
      panel.grid.major.y = element_line(size = 0.0001, linetype = 'solid', colour = "grey85"),
      panel.grid.major.x = element_blank(),
      strip.background = element_rect(fill=NA, color="grey50",linetype="solid"),
      axis.ticks = element_line(color = "black"),
      axis.ticks.length=unit(0.15, "cm"),  
      axis.title.x = element_blank(),   
      axis.text.x = element_blank(), 
      axis.title.y = element_blank(),   
      axis.text.y = element_text(color=NA), 
      panel.spacing.y = unit(10, "mm"),
      text=element_text(family="helvetica"))+
    scale_fill_manual(values = ColorsData, labels = c("Density",  "Cohort-independent density"), name = "")+
    scale_color_manual(values = ColorsData, labels = c("Density",  "Cohort-independent density"), name = "")
  # 
  

  
  scalingplotHaddock<- 
    ggplot(SynchResults_temp[SynchResults_temp$Stage<9 & SynchResults_temp$Species == "Haddock",], aes(logl, as.factor(Stage)))+
    geom_density_ridges(aes(fill = Data), color =NA, rel_min_height = 0.001, alpha = 0.2,scale = Height, quantile_lines = TRUE, quantiles = 2, bandwidth = 0.5, size = 0.3)+
    geom_density_ridges(aes(color = Data), fill = NA, rel_min_height = 0.001,  scale = Height,quantile_lines = TRUE, quantiles = 2, bandwidth = 0.5, size = 0.3)+
    theme_bw()+
    labs(x = "l (km)", y = "Age")+
    coord_cartesian(xlim = c(-50,500))+
    scale_x_continuous(limits =c(-30, 1201), expand = c(0, 0))+
    scale_y_discrete(expand = expand_scale(mult = c(0.01, 0.17))) +
    theme_ridges(center_axis_labels = TRUE)+
    theme(legend.position="none",
      strip.placement = "outside",
      strip.background.y = element_blank(), 
      strip.text.y = element_blank(),
      panel.grid.major.y = element_line(size = 0.0001, linetype = 'solid', colour = "grey85"),
      panel.grid.major.x = element_blank(),
      strip.background = element_rect(fill=NA, color="grey50",linetype="solid"),
      axis.ticks = element_line(color = "black"),
      axis.ticks.length=unit(0.15, "cm"),  
      axis.title.y = element_text(color="grey10", size = 9, margin = margin(t = 0, r = 8, b = 0, l = 0)),   
      axis.text.y = element_text(color="grey40", size = 9),   
      axis.title.x = element_text(color="grey10", size = 9),   
      axis.text.x = element_text(color="grey40", size = 9),   
      panel.spacing.y = unit(10, "mm"),
      text=element_text(family="helvetica"))+
    scale_fill_manual(values = ColorsData, labels = c("Density",  "Cohort-independent density"), name = "Variable")+
    scale_color_manual(values = ColorsData, labels = c("Density",  "Cohort-independent density"), name = "Variable")
  # 
  # 
  Ro0h<-Ro0[Ro0$Species == "Haddock",]
  
  rho0plotHaddock<-
    ggplot(SynchResults_temp[SynchResults_temp$Stage<9 & SynchResults_temp$Species == "Haddock",], aes(logitrho0, as.factor(Stage)))+
    geom_density_ridges(aes(fill = Data), color =NA, rel_min_height = 0.001, alpha = 0.2,scale = Height, quantile_lines = TRUE, quantiles = 2, bandwidth = 0.01, size = 0.3)+
    geom_density_ridges(aes(color = Data), fill = NA, rel_min_height = 0.001, bins = 100, scale = Height,quantile_lines = TRUE, quantiles = 2, bandwidth = 0.01, size = 0.3)+
    theme_bw()+
    labs(x = expression(rho[0]), y = "Age")+
    coord_cartesian(xlim = c(0,1))+
    scale_x_continuous(limits =c(0, 1), expand = c(0, 0))+
    scale_y_discrete(expand = expand_scale(mult = c(0.01, 0.17))) +
    theme_ridges(center_axis_labels = TRUE)+
    theme(
      legend.position="none",
      strip.placement = "outside",
      strip.background.y = element_blank(), 
      strip.text.y = element_blank(),
      panel.grid.major.y = element_line(size = 0.0001, linetype = 'solid', colour = "grey85"),
      panel.grid.major.x = element_blank(),
      strip.background = element_rect(fill=NA, color="grey50",linetype="solid"),
      axis.ticks = element_line(color = "black"),
      axis.ticks.length=unit(0.15, "cm"),  
      axis.title.y = element_blank(),   
      axis.text.y = element_text(color=NA, size = 9), 
      axis.title.x = element_text(color="grey10", size = 9),   
      axis.text.x = element_text(color="grey40", size = 9), 
      panel.spacing.y = unit(10, "mm"),
      text=element_text(family="helvetica"))+
    scale_fill_manual(values = ColorsData, labels = c("Density",  "Cohort-independent density"), name = "")+
    scale_color_manual(values = ColorsData, labels = c("Density",  "Cohort-independent density"), name = "")
  
  RoIh<-RoI[RoI$Species == "Haddock",]
  
  rhoInfplotHaddock<-
    ggplot(SynchResults_temp[SynchResults_temp$Stage<9 & SynchResults_temp$Species == "Haddock",], aes(logitrhoinf, as.factor(Stage)))+
    geom_density_ridges(aes(fill = Data), color =NA, rel_min_height = 0.001, alpha = 0.2,scale = 1.1, quantile_lines = TRUE, quantiles = 2, bandwidth = 0.01, size = 0.3)+
    geom_density_ridges(aes(color = Data), fill = NA, rel_min_height = 0.001, bins = 100, scale = 1.1,quantile_lines = TRUE, quantiles = 2, bandwidth = 0.01, size = 0.3)+
    theme_bw()+
    labs(x = expression(rho[infinity]), y = "Age")+
    coord_cartesian(xlim = c(0,1))+
    scale_x_continuous(limits =c(0, 1), expand = c(0, 0))+
    scale_y_discrete(expand = expand_scale(mult = c(0.01, 0.17))) +
    theme_ridges(center_axis_labels = TRUE)+
    theme(legend.position="top",
      legend.justification = "center",
      strip.placement = "outside",
      legend.text = element_text(size = 11),
      strip.background.y = element_blank(), 
      strip.text.y = element_blank(),
      panel.grid.major.y = element_line(size = 0.0001, linetype = 'solid', colour = "grey85"),
      panel.grid.major.x = element_blank(),
      strip.background = element_rect(fill=NA, color="grey50",linetype="solid"),
      axis.ticks = element_line(color = "black"),
      axis.ticks.length=unit(0.15, "cm"),  
      axis.title.y = element_blank(),   
      axis.text.y = element_text(color=NA, size = 9),  
      axis.title.x = element_text(color="grey10", size = 9),   
      axis.text.x = element_text(color="grey40", size = 9), 
      panel.spacing.y = unit(10, "mm"),
      text=element_text(family="helvetica"))+
    scale_fill_manual(values = ColorsData, labels = c("Density",  "Cohort-independent density"), name = "")+
    scale_color_manual(values = ColorsData, labels = c("Density",  "Cohort-independent density"), name = "")
  
  legend<-as_ggplot(get_legend(rhoInfplotHaddock))+ theme(plot.margin = margin(0,0,0,0, "cm"))
  
  
  Sp1 <- "Cod"
  Sp2 <- "Haddock"
  # Create a text grob
  Sp1 <- text_grob(Sp1, rot = 90, size = 11, just = "top", family="helvetica")
  Sp2 <- text_grob(Sp2, rot = 90, size = 11, just = "top", family="helvetica")
  # Draw the text
  plot_sp1 <- as_ggplot(Sp1) + theme(plot.margin = margin(0,0,0,0, "cm"))
  plot_sp2 <- as_ggplot(Sp2) + theme(plot.margin = margin(0,0,0,0, "cm"))
  
  
  
  
  AgeSynch<-ggarrange(ggarrange(plot_sp1, scalingplotCod,  rho0plotCod , rhoInfplotCod,
                                plot_sp2, scalingplotHaddock, rho0plotHaddock, rhoInfplotHaddock+theme(legend.position="none"), 
                                labels = c("", "a)", "b)", "c)","","d)", "e)", "f)"), font.label = list(size = 12, family = "helvetica"),ncol = 4, nrow = 2,  widths = c(0.1,1.1,1,1), heights = c(1,1.18)),legend, ncol = 1, nrow = 2, widths = c(1,1), heights = c(1,0.1), align = "hv")
  

  ggsave(AgeSynch, file = paste0("RidgesSynch_",a,".tiff"),height= 16.78,width= 16.51,units="cm",dpi=800,compression="lzw")
  


###############################################################################################################
###############################################################################################################
###############################################################################################################
#                  RIBBONs
###############################################################################################################
###############################################################################################################
###############################################################################################################
ColorsData <- c("#00b4d8", "#1e6091")


SynchRibbon<-data.frame()
for(d in seq(0, 1000, 5)){
  
  temp.sp<-data.frame(RhoAt=SynchResults_temp$logitrhoinf -(SynchResults_temp$logitrhoinf -SynchResults_temp$logitrho0)*exp(-d^2/(2*SynchResults_temp$logl^2)), Species = SynchResults_temp$Species, Stage=SynchResults_temp$Stage, Offset =SynchResults_temp$Offset, Data = SynchResults_temp$Data, Resolution= SynchResults_temp$Resolution) 
  
  # Get mediana and 95% ConfInt
  temp.rho<- temp.sp %>%
    dplyr::group_by(Species, Stage, Data, Resolution)%>% #, Offset)%>%
    dplyr::summarise(Q2.5 = quantile(RhoAt, 0.025),
                     Q97.5 = quantile(RhoAt, 0.975),
                     M = median(RhoAt))%>%
    as.data.frame()
  
  SynchRibbon<-rbind(SynchRibbon, data.frame(temp.rho, Distance = d))
  
}  # // d loop 
colnames(SynchRibbon)[2]<-"Age"

MaxRanges<-SynchPoints%>%group_by(Species, Stage)%>% filter(!is.na(rho)) %>%summarise(Range = max(Distance, na.rm = TRUE))%>%as.data.frame()
colnames(MaxRanges)[2]<-"Age"

PlotRibbons<-
  ggplot(SynchRibbon)+
  geom_ribbon(aes(ymin=Q2.5, ymax=Q97.5, x = Distance, fill = as.factor(Data)),alpha = 0.3, inherit.aes = FALSE)+
  geom_line(aes(y=M, x = Distance, color = as.factor(Data)), alpha = 0.5, inherit.aes = FALSE)+
  theme_classic()+
  geom_hline(yintercept = 0, color = "grey80")+
  scale_fill_manual(values = ColorsData, labels = c("Density",  "Cohort-independent density"), name = "")+
  scale_color_manual(values = ColorsData, labels = c("Density",  "Cohort-independent density"), name = "")+
  facet_grid(as.factor(Age) ~ Species)+
  scale_x_continuous(limits =c(0, 600), expand = c(0, 0))+
  theme(
    legend.position="top",
    legend.justification = "center",
    strip.placement = "outside",
    strip.background.y = element_blank(), 
    strip.text.y = element_text(angle = 0, margin = margin(0,2.5,0,2.5, "mm")),
    strip.background = element_rect(fill=NA, color="grey50",linetype="solid"),
    axis.line.x = element_blank(),
    axis.ticks = element_line(color = "black"),
    axis.ticks.length=unit(0.15, "cm"),  
    axis.title.y = element_blank(),   
    axis.text.y = element_text(color=NA),  
    axis.title.x = element_text(color="grey30"),   
    axis.text.x = element_text(color="grey10"), 
    panel.spacing.x = unit(10, "mm"))



ggsave(PlotRibbons, file = paste0("SynchAgesRibbons_Den.",a,".tiff"),height= 16.78,width= 10.25,units="cm",dpi=800,compression="lzw")


